*###############################INDUSTRY ANALYSIS#############################
*#############################################################################

*This code produces industry pictures: Figure 6 and 7 in the paper and also produces the variable "the share of hospitality, leisure and other services" to be used in cross-country regressions

*Set Directory
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"
cd "${output}/"

***Merge data for different countries
use "${procdata}/ind_sa.dta" //seasonally adjusted industry employment data Euroepan countries
append using "${procdata}/bls.dta" //US industry data
append using "${procdata}/Canada_ind.dta" //Canada industry data
merge 1:1 country yq using "${procdata}/gdp_sa_quarter.dta" //seasonally adjusted quarterly GDP
drop c 
encode country, gen(c)
tsset c yq

replace agri_male=1 if country=="US" //it does not exist for US just a trick, it would not matter as we are summing up industries into 3 groups: we mention that agriculture exists in all countries as an industru except the US in the appendix of the paper
replace agri_female=1 if country=="US"
drop if country=="Luxembourg"

*###################################US Analysis######################################################
*This part produces Figure 6 in the paper
preserve 
keep if year>=1998 
keep if country=="US"
local mylist "construct info fin_re public leisure manu ttu bus_ad ed_health other_hh"
foreach m of local mylist{
gen `m'=`m'_male+`m'_female
}
gen female=agri_female+construct_female+info_female+fin_re_female+public_female+leisure_female+manu_female+ttu_female+bus_ad_female+ed_health_female+other_hh_female
gen male=agri_male+construct_male+info_male+fin_re_male+public_male+leisure_male+manu_male+ttu_male+bus_ad_male+ed_health_male+other_hh_male
gen all=male+female

foreach m of local mylist{
gen change_`m'=.
gen l_`m'=log(`m')
bysort country: gen pre_`m'=l_`m' if year==2019 & q==4
bysort country: egen precovid_`m'=mean(pre_`m') 
bysort country: gen post_`m'=l_`m' if year==2020 & q==2
bysort country: egen postcovid_`m'=mean(post_`m') 
}

foreach m of local mylist{
replace change_`m'=postcovid_`m'-precovid_`m'
}
foreach m of local mylist{
gen gr_`m'=.
bysort country: gen gr1_`m'=l_`m' if year==2007 & q==4
bysort country: egen gr1_`m'_=mean(gr1_`m') 
bysort country: gen gr2_`m'=l_`m' if year==2009 & q==2
bysort country: egen gr2_`m'_=mean(gr2_`m') 
}

foreach m of local mylist{
replace gr_`m'=gr2_`m'_-gr1_`m'_
}
keep if year<2020 //for pre-Covid cyclicality 1998-2019
foreach m of local mylist{
tsfilter hp `m'_cycle=l_`m', smooth(1600)
gen cyc_`m'=.
}
gen l_gdp=log(gdp_sa)
tsfilter hp gdp_cycle=l_gdp, smooth(1600)
foreach m of local mylist{
reg `m'_cycle gdp_cycle 
predict `m'_hat,xb
egen sd_`m'=sd(`m'_hat)
replace cyc_`m'=sd_`m'
drop `m'_hat sd_`m'
}
collapse change_construct change_info change_fin_re change_public change_leisure change_manu change_ttu change_bus_ad change_ed_health change_other_hh gr_construct gr_info gr_fin_re gr_public gr_leisure gr_manu gr_ttu gr_bus_ad gr_ed_health gr_other_hh cyc_construct cyc_info cyc_fin_re cyc_public cyc_leisure cyc_manu cyc_ttu cyc_bus_ad cyc_ed_health cyc_other_hh, by(country)
reshape long change_ cyc_ gr_ ,i(country) j(ind, string)
replace ind="Professional and business services" if ind=="bus_ad"
replace ind="Construction" if ind=="construct"
replace ind="Education and health services" if ind=="ed_health"
replace ind="Financial activities" if ind=="fin_re"
replace ind="Information" if ind=="info"
replace ind="Leisure and Hospitality" if ind=="leisure"
replace ind="Manufacturing" if ind=="manu"
replace ind="Other services" if ind=="other_hh"
replace ind="Public administration" if ind=="public"
replace ind="Trade, transportation and utilities" if ind=="ttu"

corr  change_ cyc_ 
local corr1 : di %4.3f r(rho)
twoway (scatter change_ cyc_ if ind=="Leisure and Hospitality" | ind=="Education and health services" | ind=="Other services" ,mlabel(ind) mcolor(red) mlabcolor(red)) (scatter change_ cyc_ if ind=="Construction" | ind=="Manufacturing" | ind=="Trade, transportation and utilities" | ind=="Information" ,mlabel(ind) mcolor(blue) mlabcolor(blue)) (scatter change_ cyc_ if ind!="Leisure and Hospitality" & ind!="Education and health services" & ind!="Other services" & ind!="Construction" & ind!="Manufacturing" & ind!="Trade, transportation and utilities" & ind!="Information",mlabel(ind) mcolor(black) mlabcolor(black)) ,  text(-0.45 0.003 "corr=`corr1'", size(small) placement(ne) box fcolor(white) lwidth(medium)) title("Covid Recession") ytitle("Log change in employment") xtitle("Cyclical volatility") xlabel(0 (0.01)0.04) legend(label (1 "Female Ind") label(2 "Male Ind") label(3 "Neutral Ind") r(1)) ylab(,nogrid) graphregion(color(white)) name(cyc, replace)
graph export covid_us.png, replace
corr  gr_ cyc_ 
local corr1 : di %4.3f r(rho)
twoway (scatter gr_ cyc_ if ind=="Leisure and Hospitality" | ind=="Education and health services" | ind=="Other services" ,mlabel(ind) mcolor(red) mlabcolor(red)) (scatter gr_ cyc_ if ind=="Construction" | ind=="Manufacturing" | ind=="Trade, transportation and utilities" | ind=="Information"  ,mlabel(ind) mcolor(blue) mlabcolor(blue)) (scatter gr_ cyc_ if ind!="Leisure and Hospitality" & ind!="Education and health services" & ind!="Other services" & ind!="Construction" & ind!="Manufacturing" & ind!="Trade, transportation and utilities" & ind!="Information",mlabel(ind) mcolor(black) mlabcolor(black)) ,  text(-0.18 0.003 "corr=`corr1'", size(small) placement(ne) box fcolor(white) lwidth(medium)) title("Great Recession") ytitle("Log change in employment") xtitle("Cyclical volatility") xlabel(0 (0.01)0.04)  legend(label (1 "Female Ind") label(2 "Male Ind") label(3 "Neutral Ind") r(1)) ylab(,nogrid) graphregion(color(white)) name(cyc2, replace)
graph export greatrecession_us.png, replace
restore
*###################################End of US Analysis######################################################



*######################################################################################################
*###################################Main Analysis######################################################
keep if year>=2008 //Europe is available after this date
drop if year==2020 & q>=3 //we are focusing at the depth of the recession

local mylist "agri construct info fin_re public leisure manu ttu bus_ad ed_health other_hh"

foreach m of local mylist{
gen `m'=`m'_male+`m'_female
}
gen female=agri_female+construct_female+info_female+fin_re_female+public_female+leisure_female+manu_female+ttu_female+bus_ad_female+ed_health_female+other_hh_female
gen male=agri_male+construct_male+info_male+fin_re_male+public_male+leisure_male+manu_male+ttu_male+bus_ad_male+ed_health_male+other_hh_male
gen all=male+female

gen ind_female_w=leisure_female+ed_health_female+other_hh_female
gen ind_female_m=leisure_male+ed_health_male+other_hh_male
gen ind_male_w=construct_female+manu_female+info_female+agri_female
gen ind_male_m=construct_male+manu_male+info_male+agri_male
gen ind_neutral_w=fin_re_female+public_female+bus_ad_female+ttu_female
gen ind_neutral_m=fin_re_male+public_male+bus_ad_male+ttu_male

gen ind_female=ind_female_m+ind_female_w
gen ind_male=ind_male_m+ind_male_w
gen ind_neutral=ind_neutral_m+ind_neutral_w

******This produces the cross-country hosptitality variable
preserve
gen hospit_other_share=(leisure+other_hh)/all //leisure industry includes hospitality and leisure for the US, arts and accommodation for Europe
keep if year==2019
collapse hospit_other_share, by(country)
save "${procdata}/social_ind.dta", replace //the average share of hospitality, leisure and other sevrices in 2019 to be used in regressions
restore


***************************************3 Industry: Female Male Neutral**********************************
********************************************************************************************************
*#######################################################################################################

keep ind_female_w ind_female_m ind_male_w ind_male_m ind_neutral_w ind_neutral_m ind_female ind_male ind_neutral all male female gdp_sa country year q yq c

local mylist "ind_female ind_male ind_neutral"
local countrylist " Austria   Belgium Canada Czechia Denmark  Estonia Finland France Germany Greece Hungary Iceland Ireland Italy  Latvia  Lithuania   Netherlands  Norway Poland  Portugal  Romania  Slovakia  Slovenia  Spain  Sweden   Switzerland UK US"

foreach m of local mylist{
gen l_`m'=log(`m')
}
gen l_gdp=log(gdp_sa)

foreach m of local mylist{
gen change_`m'=.

bysort c: gen pre_`m'=l_`m' if year==2019 & q==4
bysort c: egen precovid_`m'=mean(pre_`m') 
bysort c: gen post_`m'=l_`m' if year==2020 & q==2
bysort c: egen postcovid_`m'=mean(post_`m') 
}

foreach m of local mylist{
replace change_`m'=postcovid_`m'-precovid_`m'
}

tsset c yq


keep if year<2020 & year>=2008 //Cyclicality behavior is calculated for the pre-Covid period

tsfilter hp ind_female_cycle=l_ind_female, smooth(1600)
tsfilter hp ind_male_cycle=l_ind_male, smooth(1600)
tsfilter hp ind_neutral_cycle=l_ind_neutral, smooth(1600)
tsfilter hp gdp_cycle=l_gdp, smooth(1600)

gen cyc_female=.
gen cyc_male=.
gen cyc_neutral=.
foreach c of local countrylist{
reg ind_female_cycle gdp_cycle if country=="`c'"
predict hat,xb
egen sd=sd(hat)
replace cyc_female=sd if country=="`c'"
drop hat sd
reg ind_male_cycle gdp_cycle if country=="`c'"
predict hat,xb
egen sd=sd(hat)
replace cyc_male=sd if country=="`c'"
drop hat sd
reg ind_neutral_cycle gdp_cycle if country=="`c'"
predict hat,xb
egen sd=sd(hat)
replace cyc_neutral=sd if country=="`c'"
drop hat sd
}

keep if year==2019 //Female share of industries is calculated only for the most recent year

gen withinfemshare_male=.
replace withinfemshare_male=ind_male_w*100/ind_male //female share in male industries
gen withinfemshare_female=.
replace withinfemshare_female=ind_female_w*100/ind_female //female share in female industries
gen withinfemshare_neutral=.
replace withinfemshare_neutral=ind_neutral_w*100/ind_neutral //female share in neutral industries


collapse change_ind_female change_ind_male change_ind_neutral cyc_female cyc_male cyc_neutral withinfemshare_male withinfemshare_female withinfemshare_neutral, by(country)


reshape long change_ind_ cyc_ withinfemshare_,i(country) j(ind, string)

corr  change_ind_ withinfemshare_ // Figure 7-b in the paper
local corr1 : di %4.3f r(rho)
twoway (scatter change_ind_ withinfemshare_ if ind=="female", mlabel(country) mcolor(red) mlabcolor(red)) (scatter change_ind_ withinfemshare_ if ind=="male", mlabel(country) mcolor(blue) mlabcolor(blue)) (scatter change_ind_ withinfemshare_ if ind=="neutral", mlabel(country) mcolor(black) mlabcolor(black)), text(-0.25 10 "corr=`corr1'", size(small) placement(ne) box fcolor(white) lwidth(medium)) ytitle("Log change in employment") xtitle("Female share") ylabel(-0.25 (0.05) 0.05) xlabel(10 (20) 90)  graphregion(color(white)) legend(label (1 "Female Ind") label(2 "Male Ind") label(3 "Neutral Ind") r(1)) ylab(,nogrid) name(t3, replace)
graph export change_femshare_3.png, replace


corr  cyc_ withinfemshare_ // Figure 7-a in the paper
local corr1 : di %4.3f r(rho)

twoway (scatter cyc_ withinfemshare_  if ind=="female", mlabel(country) mcolor(red) mlabcolor(red)) (scatter cyc_ withinfemshare_ if ind=="male", mlabel(country) mcolor(blue) mlabcolor(blue)) (scatter cyc_ withinfemshare_ if ind=="neutral", mlabel(country) mcolor(black) mlabcolor(black)), text(0 10 "corr=`corr1'", size(small) placement(ne) box fcolor(white) lwidth(medium)) title("") xtitle("Female share") ytitle("Cyclical volatility") ylabel(0 (0.01)0.04) xlabel(10 (20) 90)   graphregion(color(white)) legend(label (1 "Female Ind") label(2 "Male Ind") label(3 "Neutral Ind") r(1)) ylab(,nogrid) name(ww, replace)
graph export cyc_femshare_3.png, replace



