*******************Calculates yearly averages of hours worked for subgroups and 27 countries*************
*******************************************************************************************************
clear all

*Set Directory

gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"

cd "${output}"
use "${rawdata}/LFS_27countries_98_19.dta"

***********************************************************
keep if age>=22 & age<=62 //20_64

*****DEFINE VARIABLES*************************************

rename refyear year
rename hourreas reason_diffwork
rename nowkreas reason_nowork

**********************************************************
gen male=.
replace male=1 if sex==1
replace male=0 if sex==2

gen female=.
replace female=1 if sex==2
replace female=0 if sex==1 

gen employed=. 
replace employed=1 if ilostat==1
replace employed=0 if ilostat==2 | ilostat==3 | ilostat==4 //unemployed, inactive, military


*******HOURS VARIABLES*************************************
gen hours_1=. //main job
replace hours_1= hwactual if hwactual>=0 & hwactual<=98  //  to capture positive hours even if not employed; gives exactly the same estimate as there are no positive hours if not employed
replace hours_1=. if (hwactual==99 | hwactual==.) & (wstator==1) & employed==1 //employed, claim worked but undefined
replace hours_1=0 if (hwactual==99 | hwactual==.) & (wstator==2 | wstator==3 | wstator==4| wstator==5) //did not work but undefined 

keep if hours_1!=. & hours_1!=99 // to go to the next step this is needed otherwise undefined values will be true values

replace hours_1=hwusual if (hours_1<hwusual) & ( reason_diffwork==11 | reason_diffwork==12 | reason_nowork==7 ) //if worked less due to holidays (bank holidays, annual holidays) or no work at all due to holidays
replace hours_1=hwusual if (hours_1<hwusual) & ( reason_nowork==0 ) & country=="UK" & year==2001 //bad weather is unusually high in that year a possible switch with holidays as discussed by Nicola. 


******************SELECTION************************************************
*Everyone whose actual hours are defined including people who do not work (0s) 
keep if hours_1!=. & hours_1!=99 //only if main job is well defined, this cleaning cleans only if we have to use usual hours and it happens to be undefined
****************************************************************************
gen hours_2=0 //secondjob
replace hours_2=hwactua2 if hwactua2>=0 & hwactua2<=98 
****************************************************************************
gen hours=hours_1+hours_2 //all jobs   MAIN VARIABLE
label variable hours "hours with extensive margin_ MAIN VARIABLE"
label variable hours_1 "hours main job"
label variable hours_2 "hours additional jobs"
****************************************************************************
preserve
keep if country=="DE" | country=="ES" | country=="NL" | country=="UK" //4 of our 6 countries
save "${rawdata}/4countries_98_19.dta", replace
restore


tempfile a
save `a'
*****Size of the data in each year-country****************
gen p=1
bysort country year: egen c_total=sum(p)
*****Save data size in excel
collapse c_total, by(country year)
reshape wide c_total, i(year) j(country,string)
export excel using "datasize_27c_20_64", firstrow(variables) replace 
**********************************************************

****************************************
clear 
use `a.dta'
********Calculate total hours by group for the shares*********************************************
bysort country year: asgen mhours=hours, w(coeff)
bysort country year: asgen memp=employed, w(coeff)

******************Calculate average hours by group**********************
collapse hours mhours memp employed [pweight=coeff], by(country year male)

gen hours_male=hours if male==1
gen hours_female=hours if male==0
gen emp_male=employed if male==1
gen emp_female=employed if male==0

collapse hours_male hours_female emp_male emp_female memp mhours, by(country year)
save "${procdata}/LFS_27countries_20_64_aggregates.dta", replace


