******************************PRE-POST COVID****************************************************
****************************************************************************************************************
***************************************************************************************************************
***This file produces:
*1-) Figure 3,4,5
*2-) Table 2,3,4,5
*3-) Table 6
*4-) figure A3
clear all
*Set Directory

gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"

cd "${output}"

use "${procdata}/ALL_indices.dta"

merge 1:1 country using "${procdata}/postcovid.dta"
drop _merge
merge 1:1 country using "${procdata}/precovid.dta"
drop _merge
merge 1:1 country using "${procdata}/social_ind.dta"
drop _merge

drop if country=="Luxembourg" //

**************************************************
label variable change_allhour "Hour Change"
label variable change_allemp "Emp Change"
label variable female_hours_2019 "Female Hours"
label variable index_closure_share "School Closure Index"
label variable change_gdp "Change in GDP"
label variable hospit_other_share "Share of Hospitality"
label variable tempworker "Emp Protection (temp worker)"
label variable change_relhour "Hour(f/m) Change"
label variable change_relemp "Emp (f/m) Change"
label variable telework_dingel "Teleworkable fraction"
label variable chilcare_oblig "Share with Childcare Obligations"

*************Descriptive Table for 6 countries***************
preserve 
keep if country=="UK" | country=="US" | country=="Canada" | country=="Netherlands" | country=="Spain" | country=="Germany"
keep country index_closure_share telework_dingel regularworker tempworker female_hours_2019 hospit_other_share corr_hour
export excel using "6_country_desc", firstrow(variables) replace
restore

****************Summary Regressions*********************************

***********************Change in all hours**************************
eststo clear
eststo: reg change_allhour index_closure_share 
eststo: reg change_allhour index_closure_share female_hours_2019 
eststo: reg change_allhour hospit_other_share 
eststo: reg change_allhour telework_dingel 
eststo: reg change_allhour telework_dingel hospit_other_share index_closure_share


estwide using reg1.tex, style(tex) label booktabs nogaps title(Total Hour Change \label{tab:cross_reg_allhour}) p  noconstant starlevels(* 0.1 ** 0.05 *** 0.01)  obslast s(N r2,  label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3) replace
esttab, compress  label title(Regression) p starlevels(* 0.1 ** 0.05 *** 0.01)  noconstant  obslast s(N r2, label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3)
eststo clear


*************************Change in all employment**************************
eststo clear
eststo: reg change_allemp index_closure_share 
eststo: reg change_allemp index_closure_share female_hours_2019 
eststo: reg change_allemp hospit_other_share 
eststo: reg change_allemp telework_dingel 
eststo: reg change_allemp telework_dingel hospit_other_share index_closure_share


estwide using reg2.tex, style(tex) label booktabs nogaps title(Employment Change \label{tab:cross_reg_allemp})  p noconstant starlevels(* 0.1 ** 0.05 *** 0.01) obslast s(N r2, label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3) replace
esttab, compress  label title(Regression) p starlevels(* 0.1 ** 0.05 *** 0.01) noconstant obslast s(N r2, label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3)


*************************Change in relative hours**************************

eststo clear
eststo: reg change_relhour index_closure_share
eststo: reg change_relhour index_closure_share female_hours_2019 
eststo: reg change_relhour hospit_other_share 
eststo: reg change_relhour telework_dingel 
eststo: reg change_relhour telework_dingel hospit_other_share  index_closure_share


estwide using reg3.tex, style(tex) label booktabs nogaps title(Relative Hour (f/m) Change \label{tab:cross_reg_relhour}) p noconstant starlevels(* 0.1 ** 0.05 *** 0.01)  obslast s(N r2, label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3) replace
esttab, compress  label title(Regression) p starlevels(* 0.1 ** 0.05 *** 0.01) noconstant  obslast s(N r2, label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3)

*************************Change in relative employment**************************
eststo clear
eststo: reg change_relemp index_closure_share
eststo: reg change_relemp index_closure_share female_hours_2019 
eststo: reg change_relemp hospit_other_share 
eststo: reg change_relemp telework_dingel 
eststo: reg change_relemp telework_dingel hospit_other_share index_closure_share


estwide using reg4.tex, style(tex) label booktabs nogaps title(Relative Emp (f/m) Change \label{tab:cross_reg_relemp}) p noconstant starlevels(* 0.1 ** 0.05 *** 0.01)  obslast s(N r2, label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3) replace
esttab, compress  label title(Regression) p starlevels(* 0.1 ** 0.05 *** 0.01) noconstant obslast s(N r2, label("N" "R2") fmt(0 %9.3f)) b(3)  r2(3)

reg change_allemp tempworker
reg change_allemp tempworker index_closure_share
***************************FIRST Round of Graphs**********************************************


gen predicted_change_hour=beta_hour*change_gdp //these beta's are estimated in the pre-Covid sample from a regression of relative hour to gdp cycles
gen predicted_change_emp=beta_emp*change_gdp


*##################Overall Impact##################


separate change_relhour, by(country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany"| country=="US"| country=="Canada") 
graph hbar change_relhour0 change_relhour1, nofill over(country,sort(change_relhour) label(labsize(vsmall))) legend(off) bar(1, fcolor(black) lcolor(black)) ytitle("Post-Covid log Change in (f/m) Hours")  ylabel(-0.1(0.05)0.05) ylab(,nogrid) graphregion(color(white)) name(change_relhour, replace)
graph export relchange.png, replace

separate change_relemp, by(country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany"| country=="US"| country=="Canada") 
graph hbar change_relemp0 change_relemp1, nofill over(country,sort(change_relemp) label(labsize(vsmall))) legend(off) bar(1, fcolor(black) lcolor(black)) ytitle("Post-Covid log Change in (f/m) Employment") ylabel(-0.04(0.02)0.02)  ylab(,nogrid) graphregion(color(white)) name(change_relemp, replace)
graph export relchange_emp.png, replace


*#####################################################################
separate corr_hour, by(country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US"| country=="Canada") 
graph hbar corr_hour0 corr_hour1, nofill over(country,sort(corr_hour) label(labsize(vsmall))) legend(off) bar(1, fcolor(black) lcolor(black)) ytitle("Correlation of Relative Hours (f/m) and GDP Deviations")  ylab(,nogrid) graphregion(color(white)) name(corr, replace)
graph export corr_hour.png, replace
separate corr_emp, by(country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US"| country=="Canada") 
graph hbar corr_emp0 corr_emp1, nofill over(country,sort(corr_emp) label(labsize(vsmall))) legend(off) bar(1, fcolor(black) lcolor(black)) ytitle("Correlation of Relative Employment (f/m) and GDP Deviations")  ylab(,nogrid) graphregion(color(white)) name(corr_e, replace)
graph export corr_emp.png, replace

*##################Predicted vs. Actual##############################
reg change_relhour predicted_change_hour
local r: di %4.3f e(r2)
twoway (scatter change_relhour predicted_change_hour, mlabel(country) mcolor(black) mlabcolor(black)) || (scatter change_relhour predicted_change_hour if country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US"| country=="Canada", title("Observed vs. Predicted") ytitle("Observed Change in f/m hour") xtitle("Predicted Change in f/m hour") mlabel(country) mcolor(red) mlabcolor(red)) ||  (function y=x, range(-0.12 0.1) lcolor(red)) , aspectratio(1) xscale(range(-0.12 0.1) titlegap(1)) text(1 -0.5 "R2=`r'", size(small) placement(ne) box fcolor(white) lwidth(medium)) legend(off) ylab(,nogrid) graphregion(color(white)) name(pre_post, replace) 
graph export predicted_realized.png, replace

reg change_relemp predicted_change_emp
local r: di %4.3f e(r2)
twoway (scatter change_relemp predicted_change_emp, mlabel(country) mcolor(black) mlabcolor(black)) || (scatter change_relemp predicted_change_emp if country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US"| country=="Canada", title("Observed vs. Predicted") ytitle("Observed Change in f/m employment") xtitle("Predicted Change in f/m employment") mlabel(country) mcolor(red) mlabcolor(red)) || (function y=x, range(-0.05 0.08) lcolor(red)), aspectratio(1) xscale(range(-0.05 0.08) titlegap(1)) yscale(range(-0.05 0.08) titlegap(1)) text(1 -0.5 "R2=`r'", size(small) placement(ne) box fcolor(white) lwidth(medium)) legend(off) ylab(,nogrid) graphregion(color(white)) name(pre_post_emp, replace) 
graph export predicted_realized_emp.png, replace


*#####################################################################
reg chilcare_oblig index_closure_share
local r: di %4.3f e(r2)
loc t =  _b[index_closure_share]/_se[index_closure_share]  // get the t-statistic
loc p : di %4.3f 2*ttail(e(df_r),abs(`t'))        
twoway (scatter chilcare_oblig index_closure_share, mlabel(country) mcolor(black) mlabcolor(black)) || (scatter chilcare_oblig index_closure_share if country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US"| country=="Canada",mlabel(country) mcolor(red) mlabcolor(red)) ||  (lfit chilcare_oblig index_closure_share, lcolor(red)), title("Childcare Obligations") ytitle("Employed Share with Childcare Obligations") xtitle("School Closure Index") text(10 0.2 "R2=`r'" "p-value=`p'", size(small) placement(ne) box fcolor(white) lwidth(medium)) legend(off) ylab(,nogrid) graphregion(color(white)) name(oblig, replace) 
graph export childcare_oblig_closure.png, replace

reg female_hours_2019 index_closure_share
local r: di %4.3f e(r2)
loc t =  _b[index_closure_share]/_se[index_closure_share]  // get the t-statistic
loc p : di %4.3f 2*ttail(e(df_r),abs(`t'))   
twoway (scatter female_hours_2019 index_closure_share, mlabel(country) mcolor(black) mlabcolor(black)) || (scatter female_hours_2019 index_closure_share if country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US"| country=="Canada",mlabel(country) mcolor(red) mlabcolor(red)) ||  (lfit female_hours_2019 index_closure_share, lcolor(red)), title("Female Labor Supply") ytitle("Average Female Hours (2019)") xtitle("School Closure Index") text(18 0.2 "R2=`r'" "p-value=`p'", size(small) placement(ne) box fcolor(white) lwidth(medium)) legend(off) ylab(,nogrid) graphregion(color(white)) name(fem, replace) 
graph export femalehours_closure.png, replace


