/* #############################################################################
Regression setup: Education, whites & single mothers
############################################################################# */


/*
1) Single mothers
- condition on cohab and married mothers
- otherwise, it follows the main setup

*/


* Preliminaries
clear

* Directories *
cd "${git_workdir}"

* Log File
log using "${out_dir}/Germany_DiD_SingleMothers.log", replace

* Load updated dataset
use "${local_data_encryp}/Germany_clean_paneldata.dta", clear



********************************************************************************
* Main regressions: Single Motherhood *
***************************************

* Compare mothers who are working and not working by child group 

// SPEC: Hours worked last week (daily hours and assumed 5 working days)
est clear 

preserve

* Mothers Sample
keep if sex==2 & child_grp==1 // mothers of children < 16 only


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


gen broad_cohab = .
replace broad_cohab = 1 if cohab == 1 | married == 1
replace broad_cohab = 0 if cohab == 0 & married == 0


reg hours Dt##ib1.broad_cohab     					i.birth_year_cat i.simp_migration i.educ,  robust  							   
matrix motherhood = r(table) //store reg results

reg hours Dt##ib1.broad_cohab 	Dt#i.work_type 		i.birth_year_cat i.simp_migration i.educ,  robust
matrix motherhood_occ = r(table) //store reg results

restore



// SPEC: Broad emploment
* no time effects (no quarter FE, no summer education dummies, no gender specific linear trends)
preserve

keep if sex==2 & (child_grp==1) // mothers of children < 16 only

* Time Sample
keep if year>=$samp_yr

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


gen broad_cohab = .
replace broad_cohab = 1 if cohab == 1 | married == 1
replace broad_cohab = 0 if cohab == 0 & married == 0


* Employment Regressions
reg broad_emp Dt##ib1.broad_cohab     					i.birth_year_cat i.simp_migration i.educ,  robust  							   
matrix motherhood_emp = r(table) //store reg results

reg broad_emp Dt##ib1.broad_cohab 	Dt#i.work_type 		i.birth_year_cat i.simp_migration i.educ,  robust
matrix motherhood_emp_occ = r(table) //store reg results

restore


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx" , sheet("Table 15") modify  // replace first time around

putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
//hours
putexcel B1 =  "Hours Single Mom - Kids < 16 (bench)"
putexcel B2=motherhood[1,7]
putexcel B3=motherhood[2,7]
putexcel B4=motherhood[4,7]

putexcel C1 =  "Hours Single Mom - Kids < 16 (work type)"
putexcel C2=motherhood_occ[1,7]
putexcel C3=motherhood_occ[2,7]
putexcel C4=motherhood_occ[4,7]


//employment
putexcel D1 =  "Employment Single Mom - Kids < 16 (bench)"
putexcel D2=motherhood_emp[1,7]
putexcel D3=motherhood_emp[2,7]
putexcel D4=motherhood_emp[4,7]

putexcel E1 =  "Employment Single Mom - Kids < 16 (work type)"
putexcel E2=motherhood_emp_occ[1,7]
putexcel E3=motherhood_emp_occ[2,7]
putexcel E4=motherhood_emp_occ[4,7]



********************************************************************************
********************************************************************************

log close

