/* #############################################################################
Main regression setup - for aggregate employment and hour effect
############################################################################# */

/*
main setup: (for employment and actual hours)

- no time trends allowed
- no quarterly seasonality dummies
- no dummy for education sector workers in summer time

- employment:
	- comparing Jan & Sep 2019 & Jan 2020 to MCS and Sep 2020

- actual hours:
	- comparing Jul 2018 to MCS (week 5 & 10-16) 2020
*/


* Preliminaries
clear

* Directories *
cd "${git_workdir}"

* Log File
log using "${out_dir}/Germany_DiD_aggregate.log", replace

* Load updated dataset
use "${local_data_encryp}/Germany_clean_paneldata.dta", clear



********************************************************************************
* Regression: Hours Last Week *
********************************


// SPEC 1: Hours last week, includes summer education dummies and quarter FE
est clear 

preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Overall change, without controls
reg hours Dt                                      ,  robust 
est store spec1_nocontrols  
matrix table_spec1_nocontrols = r(table) //store reg results


* Overall change, with benchmark controls
reg hours Dt                                     i.birth_year_cat i.simp_migration i.educ i.married ,  robust 
est store spec1_controls  
matrix table_spec1_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx", sheet("Table 8a") modify  // replace first time around
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Overall Hrs_lwk (no cont)"
putexcel B2=table_spec1_nocontrols[1,1] 
putexcel B3=table_spec1_nocontrols[2,1] 
putexcel B4=table_spec1_nocontrols[4,1] 

putexcel C1 =  "Overall Hrs_lwk (with cont)"
putexcel C2=table_spec1_controls[1,1] 
putexcel C3=table_spec1_controls[2,1] 
putexcel C4=table_spec1_controls[4,1] 

restore




********************************************************************************
* Regression: Broad employment *
********************************


// SPEC 2: Broad Employment-- **unweighted** regression
* no time effects (no quarter FE, no summer education dummies, no gender specific linear trends)
est clear 

preserve

* Time Sample
keep if year>=$samp_yr

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Overall change, without controls
reg broad_emp Dt                                     ,  robust 
est store spec2_nocontrols  
matrix table_spec2_nocontrols = r(table) //store reg results

* Overall change, with benchmark controls
reg broad_emp Dt                                     i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store spec2_controls  
matrix table_spec2_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx", sheet("Table 7a") modify  // replace first time around
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Broad employment (no cont)"
putexcel B2=table_spec2_nocontrols[1,1] 
putexcel B3=table_spec2_nocontrols[2,1] 
putexcel B4=table_spec2_nocontrols[4,1] 

putexcel C1 =  "Broad employment (with cont)"
putexcel C2=table_spec2_controls[1,1] 
putexcel C3=table_spec2_controls[2,1] 
putexcel C4=table_spec2_controls[4,1] 

restore


log close

