
* Preliminaries
cls
clear all

* Directories *
global raw_data "..."  //location of raw CPS data
global this_dir "..."  //main directory for output and intermediate files

* Read in raw data
use "${raw_data}/XXXXX.dta" if year >=2000 , clear //read in CPS microdata from IPUMS, replace XXXX with name of CPS file



********************************************************************************
******************************************************************************** 
* [1] Create Data Set *
***********************

* Population Sample
keep if age>=25 & age<=55
drop if occ2010>=9800 & occ2010<=9830 //drop military
drop if ind>=9670 & ind<=9870  //drop military


* Time Variable 
gen time_var = ym(year,month)  //monthly time
*gen sdate = string(time_var, "%tmmy") 
*labmask time_var, val(sdate) // label time periods with month-year


* Simple Kid Group 
gen kid_grp = .
replace kid_grp = 0 if yngch>=18 | nchild==0 //  none or adult
replace kid_grp = 1 if yngch<18  // kids < 18

gen child_grp = .
replace child_grp = 0 if nchild==0
replace child_grp = 1 if yngch<5
replace child_grp = 2 if yngch>=5 & yngch<18
replace child_grp = 0 if yngch>=18 

* Broad Employment 
* (Employment-per-capita; combines unemployed and NILF, as in our model. Excludes armed services.)
gen broad_emp = .
replace broad_emp = 0 if (empstat>=21 & empstat<=22) | (empstat>=32 & empstat<=36) 
replace broad_emp = 1 if  empstat>=10 & empstat<=12

* Broad Hours 
* (Broad Hours Index assigned 0 to those unemployed or NILF. For measurement, use hours worked last week rather than usual hours worked, given unusual short term nature of recession)

* usual hours 
gen raw_hours_usual = . 
replace raw_hours_usual = uhrsworkt if uhrsworkt~=997  & uhrsworkt~=999  //usual hours worked metric, used as a robustness check\
replace raw_hours_usual = 0 if (uhrsworkt==997  | uhrsworkt==999)  & empstat==12 
replace raw_hours_usual = 0 if broad_emp==0 //unemployed and NILF get zero hours, for extensive margin
replace raw_hours_usual = . if raw_hours_usual>(24-8)*7 // drop those with impossibly high hours

* lask week hours
gen raw_hours_lwk = .  
replace raw_hours_lwk = ahrsworkt if ahrsworkt~=999  // hours worked last week, careful with missing values coded as 999
replace raw_hours_lwk = 0 if ahrsworkt==999 & empstat==12 // assign to those 0 hours, who are employed but did not work last week (empstat == 12) 
replace raw_hours_lwk = 0 if broad_emp==0 //unemployed and NILF get zero hours, for extensive margin
replace raw_hours_lwk = . if raw_hours_lwk>(24-8)*7 // drop those with impossibly high hours



* Write out data set for seasonal adjustment
* aggregates by gender
preserve
collapse raw_hours_lwk raw_hours_usual broad_emp [pw=compwt], by(year month sex )

reshape wide raw_hours_lwk raw_hours_usual broad_emp, i(year month) j(sex)

rename raw_hours_lwk1 hrs_lwk_men_all
rename raw_hours_lwk2 hrs_lwk_wmn_all

rename raw_hours_usual1 hrs_usl_men_all
rename raw_hours_usual2 hrs_usl_wmn_all

rename broad_emp1 emp_men_all
rename broad_emp2 emp_wmn_all

tempfile agg1
save `agg1'

restore

* aggregates by gender and kid_grp
preserve
collapse raw_hours_lwk raw_hours_usual broad_emp [pw=compwt], by(year month sex kid_grp)

gen this_grp = 10*sex+kid_grp
drop sex kid_grp
reshape wide raw_hours_lwk raw_hours_usual broad_emp, i(year month) j(this_grp)

rename raw_hours_lwk10 hrs_lwk_men_none 
rename raw_hours_lwk11 hrs_lwk_men_kids
rename raw_hours_lwk20 hrs_lwk_wmn_none 
rename raw_hours_lwk21 hrs_lwk_wmn_kids

rename raw_hours_usual10 hrs_usl_men_none 
rename raw_hours_usual11 hrs_usl_men_kids
rename raw_hours_usual20 hrs_usl_wmn_none 
rename raw_hours_usual21 hrs_usl_wmn_kids

rename broad_emp10 emp_men_none 
rename broad_emp11 emp_men_kids
rename broad_emp20 emp_wmn_none 
rename broad_emp21 emp_wmn_kids

tempfile agg2
save `agg2'

restore

* aggregates by gender and child_grp
preserve

collapse raw_hours_lwk raw_hours_usual broad_emp [pw=compwt], by(year month sex child_grp)

gen this_grp = 10*sex+child_grp
drop sex child_grp
reshape wide raw_hours_lwk raw_hours_usual broad_emp, i(year month) j(this_grp)

rename raw_hours_lwk10 hrs_lwk_men_chd0
rename raw_hours_lwk11 hrs_lwk_men_chd1
rename raw_hours_lwk12 hrs_lwk_men_chd2
rename raw_hours_lwk20 hrs_lwk_wmn_chd0
rename raw_hours_lwk21 hrs_lwk_wmn_chd1
rename raw_hours_lwk22 hrs_lwk_wmn_chd2

rename raw_hours_usual10 hrs_usl_men_chd0 
rename raw_hours_usual11 hrs_usl_men_chd1
rename raw_hours_usual12 hrs_usl_men_chd2
rename raw_hours_usual20 hrs_usl_wmn_chd0 
rename raw_hours_usual21 hrs_usl_wmn_chd1
rename raw_hours_usual22 hrs_usl_wmn_chd2

rename broad_emp10 emp_men_chd0 
rename broad_emp11 emp_men_chd1
rename broad_emp12 emp_men_chd2
rename broad_emp20 emp_wmn_chd0
rename broad_emp21 emp_wmn_chd1
rename broad_emp22 emp_wmn_chd2

tempfile agg3
save `agg3'
restore



* Export for seasonal adjustment
//preserve
use `agg1', clear
merge 1:1 year month using `agg2'
tab _merge
drop _merge
merge 1:1 year month using `agg3'
tab _merge
drop _merge

save "${out_dir}/GRP_data_nonSA.dta" ,replace  //file to be read in by GP_Figure_02.do
restore

