
* OBJECTIVE: Recreate Figure 2 in Macro Annual article.

* Preliminaries
cls
clear all

* Directories *
global this_dir "..."  //main directory for output and intermediate files 


* Data *
use "${this_dir}/hrs_SA.dta",clear // seasonally adjusted data created by GP_Figure_02.do




********************************************************************************
******************************************************************************** 
* PREPARE DATA *
****************

* Time Variable
gen time_var = ym(year, month)


// Great Recession
preserve

keep if time_var>=ym(2007,11)  & time_var<=ym(2009,6) // Great Recession 
egen start_time  = min(time_var)
gen  time_index  = time_var - ym(2007,11) 


* Define variables
foreach var of varlist emp_* hrs_*{
	gen GR_`var' = `var' //great recession
}

* save data
keep time_index GR_*
tempfile dat_GR
save `dat_GR'

restore
 

// Pandemic Recession
preserve

keep if time_var>=ym(2020,2)   // Pandemic recession (up to available data)  
egen start_time  = min(time_var)
gen  time_index  = time_var - ym(2020,2) 


* Define variables
foreach var of varlist emp_* hrs_* {
	gen PR_`var' = `var'  //pandemic recession
}

* save data
keep time_index PR_*

tempfile dat_P
save `dat_P'

restore
 
 
// Make Figures

* Combine Data
use "`dat_GR'", clear
merge 1:1 time_index  using "`dat_P'"
drop _merge


* Female-Male Ratios (Gender Gaps) by gender and kid group
gen G2_emp_none = GR_emp_wmn_none/GR_emp_men_none
gen G2_emp_kids = GR_emp_wmn_kids/GR_emp_men_kids
gen P2_emp_none = PR_emp_wmn_none/PR_emp_men_none
gen P2_emp_kids = PR_emp_wmn_kids/PR_emp_men_kids

gen G2_lwk_none = GR_hrs_lwk_wmn_none/GR_hrs_lwk_men_none
gen G2_lwk_kids = GR_hrs_lwk_wmn_kids/GR_hrs_lwk_men_kids
gen P2_lwk_none = PR_hrs_lwk_wmn_none/PR_hrs_lwk_men_none
gen P2_lwk_kids = PR_hrs_lwk_wmn_kids/PR_hrs_lwk_men_kids


* Normalizations for plotting variables
foreach var of varlist G2_* P2_* {
	local var_norm  = `var'[1]
	gen plot_`var'    = 100*ln(`var'/`var_norm')
}



********************************************************************************
******************************************************************************** 
* FINAL PAPER FIGURES *
***********************

* Create Figures
keep time_index plot_*


// (I) Employment last week by gender and kid group
#delimit ;
twoway (line plot_G2_emp_none time_index, lwidth(0.5) lcolor(navy) lpattern(shortdash_dot)) || (line plot_G2_emp_kids time_index, lwidth(0.5)  lcolor(maroon) lpattern(shortdash_dot))
 || (line plot_P2_emp_none time_index,lwidth(0.35) lcolor(navy)) || (line plot_P2_emp_kids time_index,lwidth(0.35) lcolor(maroon)), /*xscale(range(0 12)) xlabel(0(1)12)*/
name(GP_FIG1,replace) graphregion(color(white)) ytitle("Change in gender gap in employment", margin(r=1)) xtitle("Months since recession start") 
legend( label(1 "Great Rec., no kids") label(2 "Great Rec., with kids") label(3 "Pandemic rec., no kids") label(4 "Pandemic rec., with kids") row(2) ring(1) )  ;
#delimit cr
graph export "${this_dir}/Figure_2.png",replace



// (II) Hours last week by gender and kid group
#delimit ;
twoway (line plot_G2_lwk_none time_index, lwidth(0.5) lcolor(navy) lpattern(shortdash_dot)) || (line plot_G2_lwk_kids time_index, lwidth(0.5)  lcolor(maroon) lpattern(shortdash_dot))
 || (line plot_P2_lwk_none time_index,lwidth(0.35) lcolor(navy)) || (line plot_P2_lwk_kids time_index,lwidth(0.35) lcolor(maroon)), /*xscale(range(0 12)) xlabel(0(1)12)*/
name(GP_FIG2,replace) graphregion(color(white)) ytitle("Change in gender gap in hours", margin(r=1)) xtitle("Months since recession start") 
legend( label(1 "Great Rec., no kids") label(2 "Great Rec., with kids") label(3 "Pandemic rec., no kids") label(4 "Pandemic rec., with kids") col(1) ring(0) pos(4))  ;
#delimit cr
graph export "${this_dir}/GP comps/Figure_A4.png",replace



