

* Preliminaries
cls
clear all
set maxvar 20000
set matsize 2000
set emptycells drop

* Directories *
global raw_data ".../Raw Data" 
global out_dir ".../Output/USA" 
cd "${out_dir}"

* Shortcut to Data: 
use "${out_dir}/proc data/Master_MacroAnnual_Data.dta" if year>=2019, replace  // cleaned data from last run of "0 macro annual final.do"

* Log File
log using "${out_dir}/decompositions/USA_decomp.log", replace

* Preliminaries *
global country_outfile = "USA_decomp.xlsx" //for saving results


* Additional Sample Restrictions
keep if year>=2019
drop if year==2020 & month>=10


********************************************************************************
* Extract coefficients and shares for Hours regressions *
*********************************************************

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.
drop if Dt==.

// drop if worktypes only occur pre- or post-pandemic
preserve
gen ncount=1
collapse (sum) ncount [pw=wtfinl],by(work_type Dt sex)

bys work_type: gen work_panel = _N
sum work_panel
gen flag_work_panel = .
replace flag_work_panel = work_panel~=4 // work type appears in both periods
//replace flag_work_panel = 1 if work_panel==1 //work type only appears before or after pandemic -> bad category

collapse flag_work_panel, by(work_type) //get rid of repeated obs before merging

keep work_type flag_work_panel
tempfile dat_work_panel
save "`dat_work_panel'"
restore

merge m:1 work_type using "`dat_work_panel'"
tab _merge 
keep if _merge==3
drop _merge

sum flag_work_panel // tiny percentage of population, ok to drop
keep if flag_work_panel==0 //drop work types that done appear both befoe and after

* Normalize unemployed group to missisng category (below exploit that this is "largest" group number)
qui sum work_type, de
local max_worktype_num = r(max)


**********************
* Hours Regressions *
**********************

* Regressions
reg hours_lwk ib0.Dt##ib0.child_grp##ib1.sex  Dt##ib`max_worktype_num'.work_type	c.time_var#ib1.sex	  i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=wtfinl],  robust 
est store est_beta
matrix table_beta = r(table) //store reg results


// save all regression coefficients, standard errors, p-values
putexcel set "${out_dir}/decompositions/${country_outfile}" , sheet("hours") modify  // replace first time around
putexcel A1 = "Coefficients"
putexcel A2 = "Standard Errors"
putexcel A3 = "t-stat"
putexcel A4 = "p-values"
putexcel A5 = "ll"
putexcel A6 = "ul"
putexcel A7 = "df"
putexcel A8 = "crit"
putexcel A9 = "eform"
putexcel B1 =  matrix(table_beta) 

**************************
* Employment Regressions *
**************************

reg broad_emp ib0.Dt##ib0.child_grp##ib1.sex  Dt##ib`max_worktype_num'.work_type	c.time_var#ib1.sex	  i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=wtfinl],  robust 
est store est_beta
matrix table_beta = r(table) //store reg results


// save all regression coefficients, standard errors, p-values
putexcel set "${out_dir}/decompositions/${country_outfile}" , sheet("employment") modify  // replace first time around
putexcel A1 = "Coefficients"
putexcel A2 = "Standard Errors"
putexcel A3 = "t-stat"
putexcel A4 = "p-values"
putexcel A5 = "ll"
putexcel A6 = "ul"
putexcel A7 = "df"
putexcel A8 = "crit"
putexcel A9 = "eform"
putexcel B1 =  matrix(table_beta) 




**********************
* Population Weights *
**********************

* MARCH 8, 2021 Changes: Focus decomp on "employed on eve of recession"
* NOTE:  When subsampling below, sometime small work types do not appear. To ensure
* this does not  mess up our merging, we choose the first set to be the most  encompassing
* sample (Dt=0) to  ensure we see every relevant work type the first time as a basis for subsequent matchig.

* A: Non-Pandemic Weights *
***************************

* Kid Weights
preserve
keep if Dt==0 //non-pandemic weights
keep if broad_emp==1

gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex child_grp)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex child_grp share
reshape wide share, i(child_grp) j(sex)

rename share1 men_share_1
rename share2 wom_share_1

tempfile kid_share_1
save "`kid_share_1'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("kid shares v2") sheetrep first(var)

restore


* Work Weights
preserve
keep if Dt==0 // non-pandemic weights
keep if broad_emp==1

gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex work_type)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex work_type share
reshape wide share, i(work_type) j(sex)

rename share1 men_share_1
rename share2 wom_share_1

tempfile work_share_1
save "`work_share_1'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("work shares v2") sheetrep first(var)

restore


* B: 2019 Weights *
***********************


* Kid Weights
preserve
keep if  year==2019 //pandemic weights
keep if broad_emp==1

gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex child_grp)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex child_grp share
reshape wide share, i(child_grp) j(sex)

rename share1 men_share_2
rename share2 wom_share_2

tempfile kid_share_2
save "`kid_share_2'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("kid shares v2") sheetrep first(var)

restore


* Work Weights
preserve
keep if  year==2019 //pandemic weights
keep if broad_emp==1

gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex work_type)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex work_type share
reshape wide share, i(work_type) j(sex)

rename share1 men_share_2
rename share2 wom_share_2

tempfile work_share_2
save "`work_share_2'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("work shares v2") sheetrep first(var)

restore



* C: Y-on-Y Quarters *
******************************************


* Kid Weights
preserve
keep if year==2019 & month>=4  & month<=9
keep if broad_emp==1


gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex child_grp)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex child_grp share
reshape wide share, i(child_grp) j(sex)

rename share1 men_share_3
rename share2 wom_share_3

tempfile kid_share_3
save "`kid_share_3'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("kid shares v2") sheetrep first(var)

restore


* Work Weights
preserve
keep if year==2019 & month>=4  & month<=9
keep if broad_emp==1


gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex work_type)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex work_type share
reshape wide share, i(work_type) j(sex)

rename share1 men_share_3
rename share2 wom_share_3

tempfile work_share_3
save "`work_share_3'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("work shares v2") sheetrep first(var)

restore




* D: 2020 Q1 - eve of pandemic sample *
******************************************


* Kid Weights
preserve
keep if year==2020 & month>=1  & month<=3
keep if broad_emp==1


gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex child_grp)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex child_grp share
reshape wide share, i(child_grp) j(sex)

rename share1 men_share_4
rename share2 wom_share_4

tempfile kid_share_4
save "`kid_share_4'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("kid shares v2") sheetrep first(var)

restore


* Work Weights
preserve
keep if year==2020 & month>=1  & month<=3
keep if broad_emp==1


gen ncount=1
collapse (sum) ncount [pw=wtfinl], by(sex work_type)

bys sex: egen tot_den = total(ncount)
gen share = ncount/tot_den

keep sex work_type share
reshape wide share, i(work_type) j(sex)

rename share1 men_share_4
rename share2 wom_share_4

tempfile work_share_4
save "`work_share_4'"

*export excel using "${out_dir}/decompositions/${country_outfile}", sheet("work shares v2") sheetrep first(var)

restore



************************
* WRITE OUT POP SHARES *
************************

* Kid Weights
preserve
use "`kid_share_1'", clear
merge 1:1 child_grp using "`kid_share_2'"
drop _merge
merge 1:1 child_grp using "`kid_share_3'"
drop _merge
merge 1:1 child_grp using "`kid_share_4'"
drop _merge

export excel using "${out_dir}/decompositions/${country_outfile}", sheet("kid shares") sheetrep first(var)

restore

* Work Weights
preserve
use "`work_share_1'", clear
merge 1:1 work_type using "`work_share_2'"
drop _merge
merge 1:1 work_type using "`work_share_3'"
drop _merge
merge 1:1 work_type using "`work_share_4'"
drop _merge

export excel using "${out_dir}/decompositions/${country_outfile}", sheet("work shares") sheetrep first(var)

restore


********************************************************************************
********************************************************************************
log close


